Multi-Freq-LDPy: Multiple Frequency Estimation Under Local Differential Privacy in Python

Installation.
This package can be easily installed with pip:
pip install multi-freq-ldpy

Requirements:
numpy 
numba
